.. _features:

Features
========

Technologie
-----------
- 100% Valides HTML und CSS
- :term:`Python`, :term:`Django`, :term:`jQuery`
- MySQL, Postgres, Oracle
- Apache, lighttpd, nginx
- memcached
- Sphinx

Philosphie
----------
- Klare Trennung von Daten, Logik und Design (MVC/MVT)
- Einfach anpassbar
- Skalierbar
- Geschwindigkeit hat Priorität

Verwaltung
----------
- Einfach zu verwendende und leistungsfähige Administrations-Oberfläche
- Automatische Skalierung von Bildern
- WYSIWYG-Editor für die Eingabe von Texten
- Ajax Technologie

Caching
-------
- Ausgeklügelte Caching Strategie um alle Teile der Seite vollautomatisch zu 
  cachen. Selbst personalisierte Teile, wie der Warenkorb, werden zuverlässig 
  und effizient gecacht.
- *LFS* benutzt verschieden Caching-Backends (Datei- oder Speicherbasierend).
  Inklusive `memcached <http://www.danga.com/memcached/>`_, dass bei weitem 
  schnellste und effizienteste Caching-system.

Checkout
--------
- One-Page Checkout
- Checkout mit Benutzerkonto und/oder anonym.
- Zugriff auf das Adressbuch, Bankkonten, Kreditkarten falls Checkout mit
  Benutzerkonto.
- Optionales erstellen eines Benutzerkontos während des Checkout-Prozesses.

Search Engine Optimization (SEO)
--------------------------------
- 100% Search Engine Friendly
- Hohe Performanz ("Google says speed is king" [#]_) 
- Schön geformte, sprechende URLs
- Flache URLs
- Automtisch erzeugte Seitenübersicht
- Automatische erzeugte Google-Sitemap
- Anbindung an Google Analytics Site Tracking und e-Commerce.

Lieferung
---------
- Variable Anzahl von Liefermethoden
- Einfache Verwaltung von variablen Lieferpreisen pro Liefermethode, bspw. 
  basierend auf Lieferland, Gewicht, Größe oder Gurtmaß, etc.

Zahlungsweisen
--------------
- Vorbereitet für die Bezahlung per Nachnahme, Bankkonto, PayPal und 
  Kreditkarte.
- Variable Anzahl von weiteren Zahlungsweisen
- Einfache Verwaltung von variablen Lieferpreisen pro Bezahlmethode, bspw. 
  basierend auf dem Gesamtpreis der Bestellung, Datum, etc.
  
Katalog
----------------
- Statische Seiten zur Generierung von Informationen, Landing Pages, etc.
- Cross-sells, Up-sells and Zugehörige Produkte
- Produkt Tags
- Breadcrumbs

Kategorien
----------
- Variable Struktur
- Flache URLs
- Ansicht für Produkt oder Subkategorien
- Meta-Keywords und -Description
- Einfache Zuordnung von Produkten
- Statische HTML-Block pro Kategorie
- Variables Layout pro Kategorie: Anzahl Spalten und Zeilen

Produkte
--------
- Variable Anzahl von Bildern pro Produkt
- Produkt Galerie
- Produktvarianten
- Ähnliche Produkte
- Produkt-Zubehör
- Ähnliche Produkte auf Basis von Tags
- Meta-Keywords und -Description

.. [#] http://news.cnet.com/Google-says-speed-is-king/2100-1032_3-6134247.html